@@ -49,7 +49,6 @@ using namespace boost;
 struct Controller::RequestAnalysis {
 	const LString *flags;
 	ServerKit::HeaderTable::Cell *appGroupNameCell;
-	bool unionStationSupport;
 };
 
 
@@ -189,9 +188,6 @@ Controller::fillPoolOptionsFromConfigCaches(Options &options,
 
 	options.logLevel = int(LoggingKit::getLevel());
 	options.integrationMode = psg_pstrdup(pool, mainConfig.integrationMode);
-	options.ustRouterAddress = requestConfig->ustRouterAddress;
-	options.ustRouterUsername = P_STATIC_STRING("logging");
-	options.ustRouterPassword = requestConfig->ustRouterPassword;
 	options.userSwitching = mainConfig.userSwitching;
 	options.defaultUser = requestConfig->defaultUser;
 	options.defaultGroup = requestConfig->defaultGroup;
@@ -362,7 +358,6 @@ Controller::createNewPoolOptions(Client *client, Request *req,
 	fillPoolOption(req, options.user, "!~PASSENGER_USER");
 	fillPoolOption(req, options.group, "!~PASSENGER_GROUP");
 	fillPoolOption(req, options.minProcesses, "!~PASSENGER_MIN_PROCESSES");
-	fillPoolOption(req, options.maxProcesses, "!~PASSENGER_MAX_PROCESSES");
 	fillPoolOption(req, options.spawnMethod, "!~PASSENGER_SPAWN_METHOD");
 	fillPoolOption(req, options.startCommand, "!~PASSENGER_START_COMMAND");
 	fillPoolOptionSecToMsec(req, options.startTimeout, "!~PASSENGER_START_TIMEOUT");
@@ -376,50 +371,20 @@ Controller::createNewPoolOptions(Client *client, Request *req,
 	fillPoolOption(req, options.fileDescriptorUlimit, "!~PASSENGER_APP_FILE_DESCRIPTOR_ULIMIT");
 	fillPoolOption(req, options.raiseInternalError, "!~PASSENGER_RAISE_INTERNAL_ERROR");
 	fillPoolOption(req, options.lveMinUid, "!~PASSENGER_LVE_MIN_UID");
+
+	// maxProcesses is configured per-application by the (Enterprise) maxInstances option (and thus passed
+	// via request headers). In OSS the max processes can also be configured, but on a global level
+	// (i.e. the same for all apps) using the maxInstancesPerApp option. As an easy implementation shortcut
+	// we apply maxInstancesPerApp to options.maxProcesses (which can be overridden by Enterprise).
+	options.maxProcesses = mainConfig.maxInstancesPerApp;
 	/******************/
 
 	boost::shared_ptr<Options> optionsCopy = boost::make_shared<Options>(options);
 	optionsCopy->persist(options);
 	optionsCopy->clearPerRequestFields();
-	optionsCopy->detachFromUnionStationTransaction();
 	poolOptionsCache.insert(options.getAppGroupName(), optionsCopy);
 }
 
-void
-Controller::initializeUnionStation(Client *client, Request *req, RequestAnalysis &analysis) {
-	if (analysis.unionStationSupport) {
-		Options &options = req->options;
-		ServerKit::HeaderTable &headers = req->secureHeaders;
-
-		const LString *key = headers.lookup("!~UNION_STATION_KEY");
-		if (key == NULL || key->size == 0) {
-			disconnectWithError(&client, "header !~UNION_STATION_KEY must be set.");
-			return;
-		}
-		key = psg_lstr_make_contiguous(key, req->pool);
-
-		const LString *filters = headers.lookup("!~UNION_STATION_FILTERS");
-		if (filters != NULL) {
-			filters = psg_lstr_make_contiguous(filters, req->pool);
-		}
-
-		options.transaction = unionStationContext->newTransaction(
-			options.getAppGroupName(), "requests",
-			string(key->start->data, key->size),
-			(filters != NULL)
-				? string(filters->start->data, filters->size)
-				: string());
-		if (!options.transaction->isNull()) {
-			options.analytics = true;
-			options.unionStationKey = StaticString(key->start->data, key->size);
-		}
-
-		req->beginStopwatchLog(&req->stopwatchLogs.requestProcessing, "request processing");
-		req->logMessage(string("Request method: ") + http_method_str(req->method));
-		req->logMessage("URI: " + StaticString(req->path.start->data, req->path.size));
-	}
-}
-
 void
 Controller::setStickySessionId(Client *client, Request *req) {
 	if (req->stickySession) {
@@ -477,8 +442,6 @@ Controller::onRequestBegin(Client *client, Request *req) {
 		analysis.appGroupNameCell = mainConfig.singleAppMode
 			? NULL
 			: req->secureHeaders.lookupCell(PASSENGER_APP_GROUP_NAME);
-		analysis.unionStationSupport = unionStationContext != NULL
-			&& getBoolOption(req, UNION_STATION_SUPPORT, false);
 		req->stickySession = getBoolOption(req, PASSENGER_STICKY_SESSIONS,
 			mainConfig.defaultStickySessions);
 		req->host = req->headers.lookup(HTTP_HOST);
@@ -498,7 +461,6 @@ Controller::onRequestBegin(Client *client, Request *req) {
 		if (req->ended()) {
 			return;
 		}
-		initializeUnionStation(client, req, analysis);
 		if (req->ended()) {
 			return;
 		}
