@@ -1,6 +1,6 @@
 /*
  *  Phusion Passenger - https://www.phusionpassenger.com/
- *  Copyright (c) 2014-2017 Phusion Holding B.V.
+ *  Copyright (c) 2014-2018 Phusion Holding B.V.
  *
  *  "Passenger", "Phusion Passenger" and "Union Station" are registered
  *  trademarks of Phusion Holding B.V.
@@ -558,7 +558,7 @@ private:
 
 		SKS_NOTICE("Shutdown finished");
 		serverState = FINISHED_SHUTDOWN;
-		if (shutdownFinishCallback != NULL) {
+		if (shutdownFinishCallback) {
 			shutdownFinishCallback(static_cast<DerivedServer *>(this));
 		}
 	}
