@@ -1,6 +1,6 @@
 /*
  *  Phusion Passenger - https://www.phusionpassenger.com/
- *  Copyright (c) 2010-2017 Phusion Holding B.V.
+ *  Copyright (c) 2010-2018 Phusion Holding B.V.
  *
  *  "Passenger", "Phusion Passenger" and "Union Station" are registered
  *  trademarks of Phusion Holding B.V.
@@ -34,6 +34,7 @@
 #include <unistd.h>
 #include <netdb.h>
 #include <string>
+#include <utility>
 #include <vector>
 #include <oxt/macros.hpp>
 #include <StaticString.h>
@@ -384,6 +385,19 @@ void setupNonBlockingSocket(NConnect_State & restrict_ref state,
  */
 bool connectToServer(NConnect_State &state);
 
+/**
+ * Checks whether the given TCP server is connectable. Because this check
+ * can take (in theory) an arbitrary amount of time, you must also supply
+ * a timeout. When the operation is done, the amount of time taken will be
+ * deducted from the `*timeout` value. A timeout of 100000 microseconds is
+ * recommended for most use cases.
+ *
+ * @throws IOException Something went wrong.
+ * @throws SystemException Something went wrong.
+ * @throws boost::thread_interrupted A system call has been interrupted.
+ */
+bool pingTcpServer(const StaticString &host, unsigned int port, unsigned long long *timeout);
+
 /**
  * Creates a Unix domain socket pair.
  *
@@ -629,18 +643,18 @@ void readPeerCredentials(int sock, uid_t *uid, gid_t *gid);
 #endif
 
 /**
- * Read all data from the given file until EOF.
+ * Read all data from the given file descriptor until EOF, or until `maxSize`
+ * is reached.
+ *
+ * Returns a pair `(contents, eof)`.
+ *
+ *  - `contents` is the read file contents, which is at most `maxSize` bytes.
+ *  - `eof` indicates whether the entire file has been read. If false, then it
+ *    means the amount of data is larger than `maxSize`.
  *
  * @throws SystemException
  */
-string readAll(const string &filename);
-
-/**
- * Read all data from the given file descriptor until EOF.
- *
- * @throws SystemException
- */
-string readAll(int fd);
+pair<string, bool> readAll(int fd, size_t maxSize);
 
 } // namespace Passenger
 
