@@ -1,6 +1,6 @@
 /*
  *  Phusion Passenger - https://www.phusionpassenger.com/
- *  Copyright (c) 2014 Phusion Holding B.V.
+ *  Copyright (c) 2014-2017 Phusion Holding B.V.
  *
  *  "Passenger", "Phusion Passenger" and "Union Station" are registered
  *  trademarks of Phusion Holding B.V.
@@ -45,8 +45,8 @@
 #ifdef __linux__
 	#include <sys/sysinfo.h>
 	#include <Exceptions.h>
+	#include <FileTools/FileManip.h>
 	#include <Utils/StringScanning.h>
-	#include <Utils/IOUtils.h>
 #endif
 #ifdef __APPLE__
 	#include <mach/mach.h>
@@ -912,7 +912,7 @@ private:
 			string contents;
 			bool hasContents = false;
 			try {
-				contents = readAll("/proc/meminfo");
+				contents = unsafeReadFile("/proc/meminfo");
 				hasContents = true;
 			} catch (const SystemException &) {
 			}
@@ -987,7 +987,7 @@ private:
 			string contents;
 			bool hasContents = false;
 			try {
-				contents = readAll("/proc/stat");
+				contents = unsafeReadFile("/proc/stat");
 				hasContents = true;
 			} catch (const SystemException &) {
 			}
@@ -1066,7 +1066,7 @@ private:
 			string contents;
 			bool hasContents = false;
 			try {
-				contents = readAll("/proc/vmstat");
+				contents = unsafeReadFile("/proc/vmstat");
 				hasContents = true;
 			} catch (const SystemException &) {
 			}
@@ -1154,7 +1154,7 @@ private:
 				&count);
 			if (status == KERN_SUCCESS) {
 				metrics.ramUsed = ((ssize_t) vmStat.active_count + vmStat.wire_count);
-				#if __MAC_OS_X_VERSION_MIN_REQUIRED >= 1090
+				#if __MAC_OS_X_VERSION_MIN_REQUIRED >= __MAC_10_9
 					metrics.ramUsed += vmStat.compressor_page_count;
 				#endif
 				metrics.ramUsed = metrics.ramUsed * (pageSize / 1024);
